.. aws-orgs documentation master file, created by
   sphinx-quickstart on Tue Jul 23 15:57:31 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to aws-orgs's documentation!
====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting_started
   basic_configuration
   concepts_and_workflow
   working_with_spec_files
   aws_organizations
   centralized_iam_access 


.. toctree::
   :maxdepth: 2
   :hidden:

   testing/test_awsaccounts
   testing/test_awsauth
   testing/test_awsloginprofile


:ref:`search`
